Fix Makefile thinko.

Add newest patches from current version and OpenBSD src tree.
Synch various things, should compile now.
This commit is contained in:
espie 1999-09-06 15:38:26 +00:00
parent 01b19e31e6
commit cc613e6f87
13 changed files with 310 additions and 84 deletions

View File

@ -1,4 +1,4 @@
# $OpenBSD: Makefile,v 1.22 1999/08/22 17:28:42 espie Exp $
# $OpenBSD: Makefile,v 1.23 1999/09/06 15:38:26 espie Exp $
# This is a configuration file for egcs, stable release.
@ -49,7 +49,7 @@ DIRECTORY=egcs/releases/%SUBDIR%/
# getting the right archives where they should be
MASTER_SITE_SUBDIR=gcc-2.95.1
DISTNAME= egcc-${VERSION}
DISTNAME= gcc-${VERSION}
USE_BZIP2=yes
DIST_SUBDIR=egcs

View File

@ -45,6 +45,10 @@ Boston, MA 02111-1307, USA. */
#define OBSD_HAS_CORRECT_SPECS
#include <openbsd.h>
/* mips assembler uses .set for arcane purposes. __attribute__((alias))
and friends won't work until we get recent binutils with .weakext
support. */
#undef SET_ASM_OP
/* Run-time target specifications. */
#if TARGET_ENDIAN_DEFAULT != 0

View File

@ -1,5 +1,5 @@
--- gcc/gcc.texi.orig Sat Aug 29 11:16:20 1998
+++ gcc/gcc.texi Tue Oct 13 14:28:22 1998
--- gcc/gcc.texi.orig Mon Aug 9 08:47:01 1999
+++ gcc/gcc.texi Mon Sep 6 17:05:19 1999
@@ -1,6 +1,6 @@
\input texinfo @c -*-texinfo-*-
@c %**start of header
@ -12,8 +12,8 @@
@ifinfo
@dircategory Programming
@direntry
-* gcc: (gcc). The GNU C compiler.
+* egcc: (egcc). The experimental GNU C compiler.
-* gcc: (gcc). The GNU Compiler Collection.
+* egcc: (egcc). The GNU Compiler Collection.
@end direntry
@ifset INTERNALS
@ifset USING

View File

@ -1,11 +1,11 @@
--- gcc/configure.in.orig Wed Mar 24 03:29:16 1999
+++ gcc/configure.in Wed Mar 24 03:29:54 1999
@@ -896,8 +896,6 @@
tmake_file=t-netbsd
--- gcc/configure.in.orig Wed Jul 14 02:39:26 1999
+++ gcc/configure.in Mon Sep 6 17:07:31 1999
@@ -1165,6 +1165,8 @@
changequote(,)dnl
i[34567]86-*-openbsd*)
changequote([,])dnl
+ # Remove when the math emulator is fixed
+ target_cpu_default="MASK_NO_FANCY_MATH_387"
# we need collect2 until our bug is fixed...
use_collect2=yes
;;
i[[34567]]86-*-openbsd*)
- # Remove when the math emulator is fixed
- target_cpu_default="MASK_NO_FANCY_MATH_387"
# we need collect2 until our bug is fixed...
use_collect2=yes
;;

View File

@ -0,0 +1,15 @@
--- gcc/tlink.c.orig Tue Aug 31 21:51:58 1999
+++ gcc/tlink.c Tue Aug 31 21:55:17 1999
@@ -654,7 +654,11 @@ scan_linker_output (fname)
if (dem)
sym = symbol_hash_lookup (dem->mangled, false);
else
- sym = symbol_hash_lookup (p, false);
+ {
+ if (*p == '_' && prepends_underscore)
+ ++p;
+ sym = symbol_hash_lookup (p, false);
+ }
}
}

View File

@ -1,8 +1,8 @@
--- gcc/Makefile.in.orig Thu Oct 8 14:16:01 1998
+++ gcc/Makefile.in Thu Oct 8 21:19:52 1998
@@ -456,6 +456,10 @@
PROTOIZE_INSTALL_NAME = `t='$(program_transform_name)'; echo protoize | sed -e $$t`
--- gcc/Makefile.in.orig Fri Aug 13 09:46:55 1999
+++ gcc/Makefile.in Mon Sep 6 17:09:06 1999
@@ -482,6 +482,10 @@
UNPROTOIZE_INSTALL_NAME = `t='$(program_transform_name)'; echo unprotoize | sed -e $$t`
GCOV_INSTALL_NAME = `t='$(program_transform_name)'; echo gcov | sed -e $$t`
+# documentation for cpp should not supersede default documentation
+CPP_INFO_NAME = `t='$(program_transform_name)'; echo cpp | sed -e $$t`
@ -11,7 +11,7 @@
# Actual name to use when installing a cross-compiler.
GCC_CROSS_NAME = `t='$(program_transform_cross_name)'; echo gcc | sed -e $$t`
PROTOIZE_CROSS_NAME = `t='$(program_transform_cross_name)'; echo protoize | sed -e $$t`
@@ -2097,12 +2101,14 @@
@@ -2268,12 +2272,14 @@
info: cpp.info gcc.info lang.info
cpp.info: $(srcdir)/cpp.texi
@ -28,7 +28,7 @@
dvi: gcc.dvi cpp.dvi lang.dvi
@@ -2243,6 +2249,7 @@
@@ -2420,6 +2426,7 @@
-rm -f cexp.c cexp.output TAGS
-rm -f cpp.info* cpp.??s cpp.*aux
-rm -f gcc.info* gcc.??s gcc.*aux
@ -36,7 +36,7 @@
#
# Entry points `install' and `uninstall'.
# Also use `install-collect2' to install collect2 when the config files don't.
@@ -2381,18 +2388,19 @@
@@ -2575,18 +2582,19 @@
# $(INSTALL_DATA) might be a relative pathname, so we can't cd into srcdir
# to do the install.
install-info: doc installdirs lang.install-info
@ -60,13 +60,13 @@
# Install the man pages.
install-man: installdirs $(srcdir)/gcc.1 $(srcdir)/cccp.1 lang.install-man
@@ -2405,9 +2413,9 @@
$(INSTALL_DATA) $(srcdir)/gcc.1 $(mandir)/$(GCC_INSTALL_NAME)$(manext); \
chmod a-x $(mandir)/$(GCC_INSTALL_NAME)$(manext); \
@@ -2599,9 +2607,9 @@
$(INSTALL_DATA) $(srcdir)/gcc.1 $(man1dir)/$(GCC_INSTALL_NAME)$(manext); \
chmod a-x $(man1dir)/$(GCC_INSTALL_NAME)$(manext); \
fi
- -rm -f $(mandir)/cccp$(manext)
- -$(INSTALL_DATA) $(srcdir)/cccp.1 $(mandir)/cccp$(manext)
- -chmod a-x $(mandir)/cccp$(manext)
- -rm -f $(man1dir)/cccp$(manext)
- -$(INSTALL_DATA) $(srcdir)/cccp.1 $(man1dir)/cccp$(manext)
- -chmod a-x $(man1dir)/cccp$(manext)
+ -rm -f $(mandir)/$(CPP_MAN_NAME)$(manext)
+ -$(INSTALL_DATA) $(srcdir)/cccp.1 $(mandir)/$(CPP_MAN_NAME)$(manext)
+ -chmod a-x $(mandir)/$(CPP_MAN_NAME)$(manext)

View File

@ -0,0 +1,212 @@
--- gcc/config/rs6000/sysv4.h.orig Mon Apr 12 20:22:02 1999
+++ gcc/config/rs6000/sysv4.h Sat Apr 17 01:59:58 1999
@@ -161,6 +161,8 @@
rs6000_current_abi = ABI_NT; \
else if (!strcmp (rs6000_abi_name, "linux")) \
rs6000_current_abi = ABI_V4; \
+ else if (!strcmp (rs6000_abi_name, "openbsd")) \
+ rs6000_current_abi = ABI_V4; \
else if (!strcmp (rs6000_abi_name, "solaris")) \
rs6000_current_abi = ABI_SOLARIS; \
else \
@@ -973,6 +975,7 @@
%{mlittle} %{mlittle-endian} %{mbig} %{mbig-endian} \
%{!mlittle: %{!mlittle-endian: %{!mbig: %{!mbig-endian: \
%{mcall-solaris: -mlittle -msolaris} \
+ %{mcall-openbsd: -mbig} \
%{mcall-linux: -mbig} }}}}"
#ifndef CC1_ENDIAN_BIG_SPEC
@@ -999,6 +1002,7 @@
%{mcall-aixdesc: -mbig %{cc1_endian_big} } \
%{mcall-solaris: -mlittle %{cc1_endian_little} } \
%{mcall-linux: -mbig %{cc1_endian_big} } \
+ %{mcall-openbsd: -mbig %{cc1_endian_big} } \
%{!mcall-nt: %{!mcall-aixdesc: %{!mcall-solaris: %{!mcall-linux: \
%(cc1_endian_default) \
}}}} \
@@ -1008,7 +1012,8 @@
%{!meabi: %{!mno-eabi: \
%{mrelocatable: -meabi } \
%{mcall-solaris: -mno-eabi } \
- %{mcall-linux: -mno-eabi }}} \
+ %{mcall-linux: -mno-eabi } \
+ %{mcall-openbsd: -mno-eabi }}} \
%{msdata: -msdata=default} \
%{mno-sdata: -msdata=none}"
@@ -1038,8 +1043,9 @@
%{mmvme: %(link_start_mvme) } \
%{msim: %(link_start_sim) } \
%{mcall-linux: %(link_start_linux) } \
+%{mcall-openbsd: %(link_start_openbsd) } \
%{mcall-solaris: %(link_start_solaris) } \
-%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-solaris: %(link_start_default) }}}}}}"
+%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-openbsd: %{!mcall-solaris: %(link_start_default) }}}}}}}"
#endif
#ifndef LINK_START_DEFAULT_SPEC
@@ -1095,8 +1101,9 @@
%{mmvme: %(link_os_mvme) } \
%{msim: %(link_os_sim) } \
%{mcall-linux: %(link_os_linux) } \
+%{mcall-openbsd: %(link_os_openbsd) } \
%{mcall-solaris: %(link_os_solaris) } \
-%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-solaris: %(link_os_default) }}}}}}"
+%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-openbsd: %{!mcall-solaris: %(link_os_default) }}}}}}}"
#endif
#ifndef LINK_OS_DEFAULT_SPEC
@@ -1139,8 +1146,9 @@
%{mcall-solaris: %(cpp_endian_solaris) } \
%{mcall-nt: %(cpp_endian_little) } \
%{mcall-linux: %(cpp_endian_big) } \
+ %{mcall-openbsd: %(cpp_endian_big) } \
%{mcall-aixdesc: %(cpp_endian_big) } \
- %{!mcall-solaris: %{!mcall-linux: %{!mcall-nt: %{!mcall-aixdesc: %(cpp_endian_default) }}}}}}}}"
+ %{!mcall-solaris: %{!mcall-linux: %{!mcall-openbsd: %{!mcall-nt: %{!mcall-aixdesc: %(cpp_endian_default) }}}}}}}}}"
#undef CPP_ENDIAN_DEFAULT_SPEC
#define CPP_ENDIAN_DEFAULT_SPEC "%(cpp_endian_big)"
@@ -1152,8 +1160,9 @@
%{mmvme: %(cpp_os_mvme) } \
%{msim: %(cpp_os_sim) } \
%{mcall-linux: %(cpp_os_linux) } \
+%{mcall-openbsd: %(cpp_os_linux) } \
%{mcall-solaris: %(cpp_os_solaris) } \
-%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-solaris: %(cpp_os_default) }}}}}}"
+%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-openbsd: %{!mcall-solaris: %(cpp_os_default) }}}}}}}"
#ifndef CPP_OS_DEFAULT_SPEC
#define CPP_OS_DEFAULT_SPEC ""
@@ -1166,8 +1175,9 @@
%{mmvme: %(startfile_mvme) } \
%{msim: %(startfile_sim) } \
%{mcall-linux: %(startfile_linux) } \
+%{mcall-openbsd: %(startfile_openbsd) } \
%{mcall-solaris: %(startfile_solaris) } \
-%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-solaris: %(startfile_default) }}}}}}"
+%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-openbsd: %{!mcall-solaris: %(startfile_default) }}}}}}}"
#undef STARTFILE_DEFAULT_SPEC
#define STARTFILE_DEFAULT_SPEC ""
@@ -1179,8 +1189,9 @@
%{mmvme: %(lib_mvme) } \
%{msim: %(lib_sim) } \
%{mcall-linux: %(lib_linux) } \
+%{mcall-openbsd: %(lib_openbsd) } \
%{mcall-solaris: %(lib_solaris) } \
-%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-solaris: %(lib_default) }}}}}}"
+%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-openbsd: %{!mcall-solaris: %(lib_default) }}}}}}}"
#undef LIBGCC_SPEC
#define LIBGCC_SPEC "libgcc.a%s"
@@ -1196,8 +1207,9 @@
%{mmvme: ecrtn.o%s} \
%{msim: ecrtn.o%s} \
%{mcall-linux: %(endfile_linux) } \
+%{mcall-openbsd: %(endfile_openbsd) } \
%{mcall-solaris: scrtn.o%s} \
-%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-solaris: %(endfile_default) }}}}}}"
+%{!mads: %{!myellowknife: %{!mmvme: %{!msim: %{!mcall-linux: %{!mcall-openbsd: %{!mcall-solaris: %(endfile_default) }}}}}}}"
#undef ENDFILE_DEFAULT_SPEC
#define ENDFILE_DEFAULT_SPEC ""
@@ -1334,6 +1346,48 @@
-Asystem(unix) -Asystem(posix)"
#endif
+/* OpenBSD support. */
+#ifndef LIB_OPENBSD_SPEC
+#define LIB_OPENBSD_SPEC "%{mnewlib: --start-group -lopenbsd %(libc_openbsd) --end-group } %{!mnewlib: %(libc_openbsd) }"
+#endif
+
+#ifndef LIBC_OPENBSD_SPEC
+#define LIBC_OPENBSD_SPEC "-lc%{pthread_r}%{p:_p}%{!p:%{pg:_p}}"
+#endif
+
+#ifndef STARTFILE_OPENBSD_SPEC
+#define STARTFILE_OPENBSD_SPEC "\
+%{!shared: %{pg:gcrt0.o%s} %{!pg:%{p:gcrt0.o%s} %{!p:crt0.o%s}}} \
+%{mnewlib: ecrti.o%s} \
+%{!mnewlib: %{!shared:crtbegin.o%s} %{shared:crtbeginS.o%s}}"
+#endif
+/*
+%{!mnewlib: crti.o%s %{!shared:crtbegin.o%s} %{shared:crtbeginS.o%s}}"
+*/
+
+#ifndef ENDFILE_OPENBSD_SPEC
+#define ENDFILE_OPENBSD_SPEC "\
+%{mnewlib: ecrtn.o%s} \
+%{!mnewlib: %{!shared:crtend.o%s} %{shared:crtendS.o%s}}"
+#endif
+/*
+%{!mnewlib: %{!shared:crtend.o%s} %{shared:crtendS.o%s} crtn.o%s}"
+*/
+
+#ifndef LINK_START_OPENBSD_SPEC
+#define LINK_START_OPENBSD_SPEC "-Ttext 0x400074"
+#endif
+
+#ifndef LINK_OS_OPENBSD_SPEC
+#define LINK_OS_OPENBSD_SPEC ""
+#endif
+
+#ifndef CPP_OS_OPENBSD_SPEC
+#define CPP_OS_OPENBSD_SPEC "-D__unix__ -D__OpenBSD__ \
+%{!ansi: -Dunix } \
+%{pthread:-D_POSIX_THREADS} \
+-Asystem(unix) -Asystem(OpenBSD)"
+ #endif
/* Solaris support. */
/* For Solaris, Gcc automatically adds in one of the files
/usr/ccs/lib/values-Xc.o, /usr/ccs/lib/values-Xa.o, or
@@ -1398,6 +1452,8 @@
{ "lib_mvme", LIB_MVME_SPEC }, \
{ "lib_sim", LIB_SIM_SPEC }, \
{ "lib_linux", LIB_LINUX_SPEC }, \
+ { "lib_openbsd", LIB_OPENBSD_SPEC }, \
+ { "libc_openbsd", LIBC_OPENBSD_SPEC }, \
{ "lib_solaris", LIB_SOLARIS_SPEC }, \
{ "lib_default", LIB_DEFAULT_SPEC }, \
{ "startfile_ads", STARTFILE_ADS_SPEC }, \
@@ -1405,6 +1461,7 @@
{ "startfile_mvme", STARTFILE_MVME_SPEC }, \
{ "startfile_sim", STARTFILE_SIM_SPEC }, \
{ "startfile_linux", STARTFILE_LINUX_SPEC }, \
+ { "startfile_openbsd", STARTFILE_OPENBSD_SPEC }, \
{ "startfile_solaris", STARTFILE_SOLARIS_SPEC }, \
{ "startfile_default", STARTFILE_DEFAULT_SPEC }, \
{ "endfile_ads", ENDFILE_ADS_SPEC }, \
@@ -1412,6 +1469,7 @@
{ "endfile_mvme", ENDFILE_MVME_SPEC }, \
{ "endfile_sim", ENDFILE_SIM_SPEC }, \
{ "endfile_linux", ENDFILE_LINUX_SPEC }, \
+ { "endfile_openbsd", ENDFILE_OPENBSD_SPEC }, \
{ "endfile_solaris", ENDFILE_SOLARIS_SPEC }, \
{ "endfile_default", ENDFILE_DEFAULT_SPEC }, \
{ "link_path", LINK_PATH_SPEC }, \
@@ -1423,6 +1481,7 @@
{ "link_start_mvme", LINK_START_MVME_SPEC }, \
{ "link_start_sim", LINK_START_SIM_SPEC }, \
{ "link_start_linux", LINK_START_LINUX_SPEC }, \
+ { "link_start_openbsd", LINK_START_OPENBSD_SPEC }, \
{ "link_start_solaris", LINK_START_SOLARIS_SPEC }, \
{ "link_start_default", LINK_START_DEFAULT_SPEC }, \
{ "link_os", LINK_OS_SPEC }, \
@@ -1431,6 +1490,7 @@
{ "link_os_mvme", LINK_OS_MVME_SPEC }, \
{ "link_os_sim", LINK_OS_SIM_SPEC }, \
{ "link_os_linux", LINK_OS_LINUX_SPEC }, \
+ { "link_os_openbsd", LINK_OS_OPENBSD_SPEC }, \
{ "link_os_solaris", LINK_OS_SOLARIS_SPEC }, \
{ "link_os_default", LINK_OS_DEFAULT_SPEC }, \
{ "cc1_endian_big", CC1_ENDIAN_BIG_SPEC }, \
@@ -1444,6 +1504,7 @@
{ "cpp_os_mvme", CPP_OS_MVME_SPEC }, \
{ "cpp_os_sim", CPP_OS_SIM_SPEC }, \
{ "cpp_os_linux", CPP_OS_LINUX_SPEC }, \
+ { "cpp_os_openbsd", CPP_OS_OPENBSD_SPEC }, \
{ "cpp_os_solaris", CPP_OS_SOLARIS_SPEC }, \
{ "cpp_os_default", CPP_OS_DEFAULT_SPEC },

View File

@ -0,0 +1,20 @@
--- gcc/config/openbsd.h.orig Thu Aug 26 22:30:52 1999
+++ gcc/config/openbsd.h Thu Aug 26 22:31:37 1999
@@ -165,13 +165,16 @@
/* OpenBSD assembler is hacked to have .type & .size support even in a.out
format object files. Functions size are supported but not activated
- yet (look for GRACE_PERIOD_EXPIRED in gas/config/obj-aout.c). */
+ yet (look for GRACE_PERIOD_EXPIRED in gas/config/obj-aout.c).
+ SET_ASM_OP is needed for attribute alias to work. */
#undef TYPE_ASM_OP
#undef SIZE_ASM_OP
+#undef SET_ASM_OP
#define TYPE_ASM_OP ".type"
#define SIZE_ASM_OP ".size"
+#define SET_ASM_OP ".set"
/* The following macro defines the format used to output the second
operand of the .type assembler directive. */

View File

@ -1,13 +1,11 @@
--- libstdc++/config/openbsd.ml.orig Thu Feb 25 02:26:26 1999
+++ libstdc++/config/openbsd.ml Thu Mar 25 22:20:36 1999
--- libio/testsuite/Makefile.in.orig Thu Nov 26 23:29:43 1998
+++ libio/testsuite/Makefile.in Thu Nov 26 23:29:54 1998
@@ -80,7 +80,7 @@
-@rm -f ./tmp?
just-check: site.exp
- rootme=`pwd`; export rootme; \
+ -rootme=`pwd`; export rootme; \
srcdir=${srcdir} ; export srcdir ; \
EXPECT=${EXPECT} ; export EXPECT ; \
if [ -f $${rootme}/../../expect/expect ] ; then \

View File

@ -1,11 +0,0 @@
--- libstdc++/testsuite/Makefile.in.orig Thu Nov 26 23:30:56 1998
+++ libstdc++/testsuite/Makefile.in Thu Nov 26 23:31:08 1998
@@ -57,7 +57,7 @@
-@rm -f ./tmp?
just-check: site.exp
- rootme=`pwd`; export rootme; \
+ -rootme=`pwd`; export rootme; \
srcdir=${srcdir} ; export srcdir ; \
EXPECT=${EXPECT} ; export EXPECT ; \
if [ -f $${rootme}/../../expect/expect ] ; then \

View File

@ -1,20 +1,19 @@
--- gcc/f/g77.texi.orig Thu Nov 26 23:32:00 1998
+++ gcc/f/g77.texi Thu Nov 26 23:32:33 1998
@@ -12,7 +12,7 @@
@end tex
@c %**start of header
--- gcc/f/g77.texi.orig Mon Jun 21 13:58:54 1999
+++ gcc/f/g77.texi Mon Sep 6 17:13:11 1999
@@ -1,6 +1,6 @@
\input texinfo @c -*-texinfo-*-
@c %**start of header
-@setfilename g77.info
+@setfilename eg77.info
@set last-up-date 1998-09-01
@set version-g77 0.5.24
@@ -154,7 +154,7 @@
@set last-update 1999-06-06
@set copyrights-g77 1995-1999
@@ -73,7 +73,7 @@
@ifinfo
@dircategory Programming
@direntry
-* g77: (g77). The GNU Fortran compiler.
+* eg77: (eg77). The experimental GNU Fortran compiler.
@end direntry
@node Top, Copying,, (DIR)
@top Introduction
@ifset INTERNALS
@ifset USING

View File

@ -1,6 +1,6 @@
--- gcc/f/Make-lang.in.orig Thu Nov 26 23:33:28 1998
+++ gcc/f/Make-lang.in Thu Nov 26 23:36:16 1998
@@ -251,7 +251,7 @@
--- gcc/f/Make-lang.in.orig Mon Jun 7 08:44:57 1999
+++ gcc/f/Make-lang.in Mon Sep 6 17:14:47 1999
@@ -229,7 +229,7 @@
esac
if [ -f lang-f77 ]; then \
rm -f $(srcdir)/f/g77.info-*; \
@ -9,26 +9,26 @@
else true; fi
f/g77.dvi: $(srcdir)/f/g77.texi $(srcdir)/f/bugs.texi \
@@ -363,17 +363,17 @@
*) rm -f lang-f77;; \
@@ -347,17 +347,17 @@
*) rm -f $(libsubdir)/lang-f77;; \
esac
if [ -f lang-f77 -a -f f/g77.info ] ; then \
if [ -f $(libsubdir)/lang-f77 -a -f f/g77.info ] ; then \
- rm -f $(infodir)/g77.info*; \
- for f in f/g77.info*; do \
+ rm -f $(infodir)/$(G77_INSTALL_NAME).info*; \
+ for f in f/$(G77_INSTALL_NAME).info*; do \
+ rm -f $(infodir)/$(G77_INSTALL_NAME).info*; \
+ for f in f/$(G77_INSTALL_NAME).info*; do \
realfile=`echo $$f | sed -e 's|.*/\([^/]*\)$$|\1|'`; \
$(INSTALL_DATA) $$f $(infodir)/$$realfile; \
done; \
- chmod a-x $(infodir)/g77.info*; \
+ chmod a-x $(infodir)/$(G77_INSTALL_NAME).info*; \
fi
@if [ -f lang-f77 -a -f $(srcdir)/f/g77.info ] ; then \
+ chmod a-x $(infodir)/$(G77_INSTALL_NAME).info*; \
else true; fi
@if [ -f $(libsubdir)/lang-f77 -a -f $(srcdir)/f/g77.info ] ; then \
if $(SHELL) -c 'install-info --version | sed 1q | fgrep -s -v -i debian' >/dev/null 2>&1; then \
- echo " install-info --info-dir=$(infodir) $(infodir)/g77.info"; \
- install-info --info-dir=$(infodir) $(infodir)/g77.info || : ; \
+ echo " install-info --info-dir=$(infodir) $(infodir)/$(G77_INSTALL_NAME).info"; \
+ install-info --info-dir=$(infodir) $(infodir)/$(G77_INSTALL_NAME).info || : ; \
+ echo " install-info --info-dir=$(infodir) $(infodir)/$(G77_INSTALL_NAME).info"; \
+ install-info --info-dir=$(infodir) $(infodir)/$(G77_INSTALL_NAME).info || : ; \
else : ; fi; \
else : ; fi
rm -f $(libsubdir)/lang-f77
--- libstdc++/config/openbsd.ml.orig Mon Apr 26 03:30:37 1999
+++ libstdc++/config/openbsd.ml Mon Sep 6 17:11:21 1999
@@ -1,5 +1,8 @@
-# Base shared lib for OpenBSD i386
-
+# Base shared lib for OpenBSD
+# This interface schmuck isn't present before after 1.1.2
# Base shared lib for OpenBSD i386
+INTERFACE=2
+MAJOR_OFFSET=28
+MSHLINK = libstdc++.so.`expr $(INTERFACE) + $(MAJOR_OFFSET)`.0
LIBS = $(ARLIB) $(SHLIB) $(SHLINK) mshlink
LIBS = $(ARLIB) $(ARLINK) $(SHLIB) $(SHLINK) mshlink
SHFLAGS = -nostdlib -Wl,-Bshareable,-Bforcearchive
SHDEPS = -lm

View File

@ -1,11 +0,0 @@